import Graph from "graphology-types";
import { CameraState, Coordinates, Dimensions, Extent, PlainObject } from "../types.js";
export * from "./animate.js";
export * from "./array.js";
export * from "./data.js";
export * from "./easings.js";
export * from "./matrices.js";
export * from "./picking.js";
export declare function isPlainObject(value: any): boolean;
export declare function assign<T>(target: Partial<T> | undefined, ...objects: Array<Partial<T | undefined>>): T;
export declare function assignDeep<T>(target: Partial<T> | undefined, ...objects: Array<Partial<T | undefined>>): T;
export declare const requestFrame: (callback: FrameRequestCallback) => number;
export declare const cancelFrame: (requestID: number) => void;
export declare function createElement<T extends HTMLElement>(tag: string, style?: Partial<CSSStyleDeclaration>, attributes?: PlainObject<string>): T;
export declare function getPixelRatio(): number;
export declare function graphExtent(graph: Graph): {
    x: Extent;
    y: Extent;
};
export interface NormalizationFunction {
    (data: Coordinates): Coordinates;
    ratio: number;
    inverse(data: Coordinates): Coordinates;
    applyTo(data: Coordinates): void;
}
export declare function createNormalizationFunction(extent: {
    x: Extent;
    y: Extent;
}): NormalizationFunction;
export declare function zIndexOrdering<T>(_extent: Extent, getter: (e: T) => number, elements: Array<T>): Array<T>;
type RGBAColor = {
    r: number;
    g: number;
    b: number;
    a: number;
};
export declare function parseColor(val: string): RGBAColor;
export declare function rgbaToFloat(r: number, g: number, b: number, a: number, masking?: boolean): number;
export declare function floatColor(val: string): number;
export declare function indexToColor(index: number): number;
export declare function colorToIndex(r: number, g: number, b: number, _a: number): number;
export declare function getCorrectionRatio(viewportDimensions: {
    width: number;
    height: number;
}, graphDimensions: {
    width: number;
    height: number;
}): number;
export declare function matrixFromCamera(state: CameraState, viewportDimensions: {
    width: number;
    height: number;
}, graphDimensions: {
    width: number;
    height: number;
}, padding: number, inverse?: boolean): Float32Array;
export declare function getMatrixImpact(matrix: Float32Array, cameraState: CameraState, viewportDimensions: Dimensions): number;
export declare function extractPixel(gl: WebGLRenderingContext, x: number, y: number, array: Uint8Array): Uint8Array;
export declare function validateGraph(graph: Graph): void;
